@@ -9,7 +9,7 @@ use base qw( Log::Dispatch::Base );
 
 use Carp ();
 
-$VERSION = '2.07';
+$VERSION = '2.11';
 
 1;
 
@@ -118,6 +118,21 @@ sub level_is_valid
     return $LEVELS{ shift() };
 }
 
+sub would_log
+{
+    my $self = shift;
+    my $level = shift;
+
+    return 0 unless $self->level_is_valid($level);
+
+    foreach ( values %{ $self->{outputs} } )
+    {
+	return 1 if $_->_should_log($level);
+    }
+
+    return 0;
+}
+
 __END__
 
 =head1 NAME
@@ -206,6 +221,11 @@ Sends the message only to the named object.
 Returns true or false to indicate whether or not the given string is a
 valid log level.  Can be called as either a class or object method.
 
+=item * would_log( $string )
+
+Given a log level, returns true or false to indicate whether or not
+anything would be logged for that log level.
+
 =item * output( $name )
 
 Returns an output of the given name.  Returns undef or an empty list,
